#' @name areaplot-package
#'
#' @title Plot Stacked Areas and Confidence Bands as Filled Polygons
#'
#' @description
#' Plot stacked areas and confidence bands as filled polygons, or add polygons
#' to existing plots. A variety of input formats are supported, including
#' vectors, matrices, data frames, formulas, etc.
#'
#' @details
#' \emph{Plot:}
#' \tabular{ll}{
#'   \code{\link{areaplot}} \tab stacked area\cr
#'   \code{\link{confplot}} \tab confidence band
#' }
#'
#' @author Arni Magnusson.

"_PACKAGE"
